#!/bin/ksh

# This sample script will install all of the critical fixes on top of WPS 6.0.2.0 
# This includes WAS and WPS iFixes that did not make it into the shipped code for 6.0.2.0
# If you have already installed any of these updates then you MUST remove them from this script
# If you have downloaded additional fixes you can add them in at the suggested points in the file
# This script should always be installed in the <WAS_HOME>/updateinstaller directory

# Function to run the UPDI, pass in the maintenance file to install.
runUPDI() {
	echo Installing $1 $2.pak
	if [ ! -f "maintenance/$2.pak" ]
	then
		echo "File \"maintenance/$2.pak\" does not exist."
		return -1
	fi
	if ./update -silent -W maintenance.package=maintenance/$2.pak
	then
		echo "$1 $2.pak installed successfully"
		return 0
	else
		echo "Install of $2.pak failed with error code = $?"
		cd ..
		echo "Look at the log file in $PWD/logs/update/$2.install/updatelog.txt to view the error"
		cd $OLDPWD
		return -1
	fi
}


#Install the WAS iFixes here
if ! runUPDI "WAS iFix" "6.0.2.9-WS-WAS-IFPK35039"
then
	exit -1
fi

if ! runUPDI "WAS iFix" "6.0.2.13-WS-WAS-IFPK32982"
then
	exit -1
fi

if ! runUPDI "WAS iFix" "6.0.2.17-WS-WAS-IFPK32396"
then
	exit -1
fi

if ! runUPDI "WAS iFix" "6.0.2.17-WS-WAS-IFPK35426"
then
	exit -1
fi

if ! runUPDI "WAS iFix" "6.0.2.17-WS-WAS-IFPK35444"
then
	exit -1
fi

if ! runUPDI "WAS iFix" "6.0.2-WS-WAS-IFPK35285"
then
	exit -1
fi

#Install any additional WAS iFixes here

#Install the following updates only for updates from 6.0.2.0
grep "6.0.2.0" ../properties/version/WBI.product > /dev/null
if [ $? -eq 0 ]; then

	#Install the WPS iFixes here
	if ! runUPDI "WPS iFix" "6.0.2.0-WS-WBI-IFIC51328"
	then
		exit -1
	fi

	if ! runUPDI "WPS iFix" "6.0.2.0-WS-WBI-IFIY92589"
	then
		exit -1
	fi

	if ! runUPDI "WPS iFix" "6.0.2.0-WS-WBI-IFJR25492"
	then
		exit -1
	fi

	if ! runUPDI "WPS iFix" "6.0.2.0-WS-WPS-IFJR25464"
	then
		exit -1
	fi

	if ! runUPDI "WPS iFix" "6.0.2.0-WS-WBI-IFJR25487"
	then
		exit -1
	fi

	if ! runUPDI "WPS iFix" "6.0.2.0-WS-WBI-IFJR25491"
	then
		exit -1
	fi

	if ! runUPDI "WPS iFix" "6.0.2.0-WS-WBI-IFJR25494"
	then
		exit -1
	fi

	if ! runUPDI "WPS iFix" "6.0.2-WS-WBI-IFJR25525"
	then
		exit -1
	fi
fi

#Install any additional WPS iFixes here

exit 0
